@@ -292,7 +292,12 @@ namespace pan
       /** 'article' MUST have been allocated by GroupHeaders::alloc_new_article()!! */
       void load_article (const Quark& g, Article * article, const StringView& references);
 
-      void load_part (const Quark& g, const Quark& mid, const Article::Part&);
+      /** the contents of `part' are given up wholesale to our
+          local GroupHeaders.  As a side-effect, the value of `part'
+          after this call is undefined.  This is an ugly interface,
+          but it's fast and only called by one client. */
+      void load_part (const Quark& g, const Quark& mid, size_t number, size_t lines, Article::Part& part);
+
       void load_headers (const DataIO&, const Quark& group);
       void save_headers (DataIO&, const Quark& group) const;
       bool save_headers (DataIO&, const Quark& group,
