@@ -587,22 +587,38 @@ PanTreeStore :: FreeRowWalker: public PanTreeStore::WalkFunctor
   FreeRowWalker (PanTreeStore *t): store(t) {}
   virtual ~FreeRowWalker () {}
   virtual bool operator()(PanTreeStore *s, Row *r, GtkTreeIter*it, GtkTreePath *p) {
-    delete r;
+    if (store->row_dispose)
+        store->row_dispose->row_dispose (s, r);
+    else
+        delete r;
     return true; // keep marching
   }
 };
 
 void
-PanTreeStore :: pan_tree_finalize (GObject *object)
+PanTreeStore :: pan_tree_dispose (GObject *object)
 {
+  PanTreeStore * store (PAN_TREE_STORE (object));
+
   // erase the remaining nodes
-  PanTreeStore * store = PAN_TREE_STORE(object);
   FreeRowWalker walk (store);
   store->postfix_walk (walk);
+
+  // clear the sort info
+  store->sort_info->clear ();
+}
+
+void
+PanTreeStore :: pan_tree_finalize (GObject *object)
+{
+  PanTreeStore * store (PAN_TREE_STORE (object));
+
   delete store->root;
-   
   delete store->column_types;
   delete store->sort_info;
+  store->root = 0;
+  store->column_types = 0;
+  store->sort_info = 0;
 
   (*parent_class->finalize) (object);
 }
@@ -615,6 +631,7 @@ PanTreeStore :: pan_tree_class_init (PanTreeStoreClass *klass)
   parent_class = (GObjectClass*) g_type_class_peek_parent (klass);
   object_class = (GObjectClass*) klass;
 
+  object_class->dispose = pan_tree_dispose;
   object_class->finalize = pan_tree_finalize;
 }
 
@@ -658,6 +675,7 @@ PanTreeStore :: pan_tree_init (PanTreeStore * tree)
   tree->stamp = g_random_int();
   tree->n_columns = 0;
   tree->root = new RootRow ();
+  tree->row_dispose = 0;
   tree->column_types = new std::vector<GType>();
   tree->sort_paused = 0;
   tree->sort_info = new column_sort_info_t;
