@@ -169,6 +169,14 @@ struct PanTreeStore
         }
     };
 
+    struct RowDispose
+    {
+      virtual ~RowDispose () {}
+      virtual void row_dispose (PanTreeStore *store, Row* row) = 0;
+    };
+
+    void set_row_dispose (RowDispose * r) { row_dispose = r; }
+
     /** Client code _must_ call row_changed() when a row changes. */
     void row_changed (GtkTreeIter * iter);
     /** Client code _must_ call row_changed() when a row changes. */
@@ -371,7 +379,13 @@ struct PanTreeStore
         get a GtkTreeIter or GtkTreePath to it. */
     Row * root;
 
+    /** How to dispose of a row that's no longer used.
+        If this is null, we just call `delete row;' */
+    RowDispose * row_dispose;
+
+
   private: // gobject
+    static void pan_tree_dispose (GObject *);
     static void pan_tree_finalize (GObject *);
     static void pan_tree_class_init (PanTreeStoreClass *);
     static void pan_tree_model_init (GtkTreeModelIface *);
